state_year_format3: Country-year IGO membership data

state_year_format3R Documentation

Country-year IGO membership data

Description

Data on IGO membership from 1816 to 2014 at the country-year level. Each row represents one country in one year. Years are recorded at five-year intervals through 1965 and annually thereafter.

Format

A data.frame with 15,557 rows. Relevant fields:

  • ccode: Correlates of War country number. See states2016.

  • year: Calendar year.

  • state: Abbreviated state name, identical to variable names in igo_year_format3.

  • aaaid...wassen: IGO variables containing state membership status. See the Details section.

Details

Possible values for the status of a state in the IGO are:

Category Numerical value
No Membership 0
Full Membership 1
Associate Membership 2
Observer 3
Missing data -9
IGO Not In Existence -1

Use igo_recode_stateyear() to recode the numerical values as factors.

See the Codebook Version 3 IGO Data.

Note

Data distributed with igoR.

Intergovernmental Organizations (version 3), IGO Data Stata Files from the Correlates of War Project.

See the Codebook Version 3 IGO Data for the full reference.

References

Pevehouse, J. C., Nordstrom, T., McManus, R. W. & Jamison, A. S. (2020). Tracking organizations in the world: The Correlates of War IGO Version 3.0 data sets. Journal of Peace Research, 57(3), 492–503. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1177/0022343319881175")}.

See Also

countrycode::countrycode() to convert between different country code schemes.

Other data sets: igo_year_format3, states2016

Examples

data("state_year_format3")
dplyr::tibble(state_year_format3)

igoR documentation built on June 24, 2026, 9:07 a.m.