| igo_dyadic | R Documentation |
Create a dyadic version of the data. The unit of observation is a country dyad. The result summarizes joint memberships across IGOs over time.
igo_dyadic(country1, country2, year = 1816:2014, ioname = NULL)
country1, country2 |
State or vector of states to compare. Values can be any valid state name or code as specified in states2016. |
year |
Year to assess, as an integer or vector of years. |
ioname |
Optional. |
This function tries to replicate the information contained in the original
file distributed by The Correlates of War Project (dyadic_format3.dta).
That file is not included in this package due to its size.
The result is a data.frame with one row for each common
year selected via country1, country2 and year.
An additional column, dyadid, computed as (1000 * ccode1) + ccode2, is
provided to identify relationships.
For each IGO selected via ioname, or all IGOs if the default option is
used, a column using lowercase ioname as an identifier is provided with
the following coding system:
| Category | Numerical Value |
| No Joint Membership | 0 |
| Joint Full Membership | 1 |
| Missing data | -9 |
| State Not System Member | -1 |
See the igo_recode_dyadic() section for an easy way to recode the
numerical values into factors.
If one state in an IGO is a full member but the other is an associate member or observer, that IGO is not coded as a joint membership.
A coded data.frame with years and country dyads as rows
and selected IGOs as columns. See Details.
Some results from this function differ from the original data set for some
IGOs regarding "Missing data" (-9) and "State Not System Member" (-1).
However, it is not clear how to fully replicate those values.
See Codebook Version 3 IGO Data.
Codebook Version 3 IGO Data for full reference.
Pevehouse, J. C., Nordstrom, T., McManus, R. W., & Jamison, A. S. (2020). Tracking organizations in the world: The Correlates of War IGO Version 3.0 data sets. Journal of Peace Research, 57(3), 492–503. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1177/0022343319881175")}.
state_year_format3, states2016, igo_search().
usa_esp <- igo_dyadic("USA", "Spain")
nrow(usa_esp)
ncol(usa_esp)
dplyr::tibble(usa_esp)
# Use custom arguments.
custom <- igo_dyadic(
country1 = c("France", "Germany"), country2 = c("Sweden", "Austria"),
year = 1992:1993, ioname = "EU"
)
dplyr::glimpse(custom)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.