igo_search: Search for IGOs

View source: R/igo_search.R

igo_searchR Documentation

Description

Searches for IGOs by name or regular expression.

Usage

igo_search(pattern = NULL, exact = FALSE)

Arguments

pattern

A regular expression used to match IGO names and identifiers. If NULL, all IGOs in igo_year_format3 are returned. Integer values are accepted.

exact

A logical value. If TRUE, pattern is anchored to require a complete match.

Details

The information for each IGO is retrieved from the latest year available in igo_year_format3.

The label column provides a cleaned version of longorgname.

Value

A data.frame with IGO identifiers, names, dates and other metadata from the latest available year for each IGO.

Codebook Version 3 IGO Data for the full reference.

References

Pevehouse, J. C., Nordstrom, T., McManus, R. W. & Jamison, A. S. (2020). Tracking organizations in the world: The Correlates of War IGO Version 3.0 data sets. Journal of Peace Research, 57(3), 492–503. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1177/0022343319881175")}.

See Also

igo_year_format3.

Other query functions: igo_search_states()

Examples

# Return all values.
library(dplyr)
all <- igo_search()

all %>% tibble()

# Search by pattern.
igo_search("EU") %>%
  select(ionum:orgname) %>%
  tibble()

igo_search("EU", exact = TRUE) %>%
  select(ionum:orgname) %>%
  tibble()

# Search by numeric identifier.
igo_search(10) %>%
  select(ionum:orgname) %>%
  tibble()

igo_search(10, exact = TRUE) %>%
  select(ionum:orgname) %>%
  tibble()

# Search with a regular expression.
igo_search("NAFTA|UN|EU") %>%
  select(ionum:orgname) %>%
  tibble()

# Search for several exact identifiers.
igo_search("^NAFTA$|^UN$|^EU$") %>%
  select(ionum:orgname) %>%
  tibble()

igoR documentation built on June 24, 2026, 9:07 a.m.