igo_search: Search for an IGO

View source: R/igo_search.R

igo_searchR Documentation

Description

Search for any IGO by name or string pattern.

Usage

igo_search(pattern = NULL, exact = FALSE)

Arguments

pattern

regex pattern. If NULL, the function returns a data set with all IGOs in igo_year_format3. Integer values are accepted.

exact

Logical. When TRUE, only exact matches are returned.

Details

The information for each IGO is retrieved from the last year available in igo_year_format3.

An additional column label is provided. This column is a clean version of longorgname.

Value

A data.frame.

Codebook Version 3 IGO Data for full reference.

References

Pevehouse, J. C., Nordstrom, T., McManus, R. W., & Jamison, A. S. (2020). Tracking organizations in the world: The Correlates of War IGO Version 3.0 data sets. Journal of Peace Research, 57(3), 492–503. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1177/0022343319881175")}.

See Also

igo_year_format3.

Examples

# All values.
library(dplyr)
all <- igo_search()

all %>% tibble()

# Search by pattern.
igo_search("EU") %>%
  select(ionum:orgname) %>%
  tibble()

igo_search("EU", exact = TRUE) %>%
  select(ionum:orgname) %>%
  tibble()

# Use integers.
igo_search(10) %>%
  select(ionum:orgname) %>%
  tibble()

igo_search(10, exact = TRUE) %>%
  select(ionum:orgname) %>%
  tibble()

# Use several patterns (regex style).
igo_search("NAFTA|UN|EU") %>%
  select(ionum:orgname) %>%
  tibble()

# Use several exact patterns (regex style).
igo_search("^NAFTA$|^UN$|^EU$") %>%
  select(ionum:orgname) %>%
  tibble()


igoR documentation built on May 23, 2026, 5:08 p.m.