Learn R Programming

igoR (version 1.0.0)

igo_search: Search and find an IGO

Description

Search any IGO by name or string pattern.

Usage

igo_search(pattern = NULL, exact = FALSE)

Value

A data.frame.

Arguments

pattern

regex pattern. If NULL the function returns a dataset with all the IGOs on igo_year_format3. Integer values are accepted.

exact

Logical. When TRUE only exact matches are returned.

Details

The information of each IGO is retrieved based on the last year available on igo_year_format3.

An additional column label is provided. This column is a clean version of longorgname

References

Pevehouse, J. C., Nordstrom, T., McManus, R. W., & Jamison, A. S. (2020). Tracking organizations in the world: The Correlates of War IGO Version 3.0 datasets. Journal of Peace Research, 57(3), 492–503. tools:::Rd_expr_doi("10.1177/0022343319881175").

See Also

igo_year_format3

Examples

Run this code
# All values
library(dplyr)
all <- igo_search()

all %>% tibble()

# Search by pattern
igo_search("EU") %>%
  select(ionum:orgname) %>%
  tibble()

igo_search("EU", exact = TRUE) %>%
  select(ionum:orgname) %>%
  tibble()

# With integers
igo_search(10) %>%
  select(ionum:orgname) %>%
  tibble()

igo_search(10, exact = TRUE) %>%
  select(ionum:orgname) %>%
  tibble()

# Several patterns (regex style)
igo_search("NAFTA|UN|EU") %>%
  select(ionum:orgname) %>%
  tibble()

# Several patterns Exact (regex style)
igo_search("^NAFTA$|^UN$|^EU$") %>%
  select(ionum:orgname) %>%
  tibble()

Run the code above in your browser using DataLab