igo_search_states: Find state codes, abbreviations and names

View source: R/igo_search_states.R

igo_search_statesR Documentation

Find state codes, abbreviations and names

Description

Finds Correlates of War codes, abbreviations and names for states.

Usage

igo_search_states(state)

Arguments

state

A state name or code, or a vector of names or codes, as specified in states2016.

Value

A data.frame with Correlates of War country codes, abbreviations, names and the matching state identifiers used by state_year_format3.

Codebook Version 3 IGO Data for the full reference.

References

Pevehouse, J. C., Nordstrom, T., McManus, R. W. & Jamison, A. S. (2020). Tracking organizations in the world: The Correlates of War IGO Version 3.0 data sets. Journal of Peace Research, 57(3), 492–503. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1177/0022343319881175")}.

See Also

states2016.

Other query functions: igo_search()

Examples

library(dplyr)

igo_search_states("Spain") %>% as_tibble()

igo_search_states(c(20, 150)) %>% as_tibble()

igo_search_states("congo") %>% as_tibble()

igo_search_states(c("Germany", "papal states")) %>% as_tibble()

igo_search_states(c("FRN", "United Kingdom", 240, "italy")) %>% as_tibble()

igoR documentation built on June 24, 2026, 9:07 a.m.