View source: R/igo_state_membership.R
| igo_state_membership | R Documentation |
Extracts IGO membership records for one or more states and years.
igo_state_membership(state, year = NULL, status = "Full Membership")
state |
A state name or code, or a vector of names or codes, as specified in states2016. |
year |
An integer or vector of years to assess. If |
status |
A character vector of membership statuses to extract. See igo_year_format3 for valid statuses. |
A data.frame with one row per matching state, year, IGO and
membership status.
Codebook Version 3 IGO Data for the full reference.
Pevehouse, J. C., Nordstrom, T., McManus, R. W. & Jamison, A. S. (2020). Tracking organizations in the world: The Correlates of War IGO Version 3.0 data sets. Journal of Peace Research, 57(3), 492–503. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1177/0022343319881175")}.
igo_year_format3, igo_search_states(), states2016.
Other membership functions:
igo_dyadic(),
igo_members()
# Memberships on two different dates.
igo_state_membership("Spain", year = 1850)
igo_state_membership("Spain", year = 1870)
igo_state_membership("Spain", year = 1880:1882)
# Use the latest available year.
igo_state_membership("ZAN")[, 1:7]
# Search by state code.
igo_state_membership("2", year = 1865)
# Extract multiple membership statuses.
igo_state_membership("kosovo", status = c(
"Associate Membership", "Observer",
"Full Membership"
))
# Vectorized search.
igo_state_membership(c("usa", "spain"), year = 1870:1871)
# Use the countrycode package to add codes.
if (requireNamespace("countrycode", quietly = TRUE)) {
library(countrycode)
IT <- igo_state_membership("Italy", year = 1880)
IT$iso3c <- countrycode(IT$ccode, origin = "cown", destination = "iso3c")
head(IT)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.