| igo_year_format3 | R Documentation |
Data on intergovernmental organizations (IGOs) from 1816 to 2014 at the IGO-year level. Each row represents one IGO in one year. Years are recorded at five-year intervals through 1965 and annually thereafter.
A data.frame with
19,335 rows. Relevant
fields:
ioname: Short abbreviation for the IGO name.
orgname: Full IGO name.
year: Calendar year.
afghanistan...zimbabwe: Membership status of each state in the IGO. See
the Details section.
sdate: Start year for the IGO.
deaddate: End year for the IGO.
longorgname: Longer IGO name, including previous names.
ionum: IGO identifier in versions 2.1 and 3.0 of the data.
version: Correlates of War version number.
Possible values for the status of a state in the IGO are:
| Category | Numerical value |
| No Membership | 0 |
| Full Membership | 1 |
| Associate Membership | 2 |
| Observer | 3 |
| Missing data | -9 |
| State Not System Member | -1 |
Use igo_recode_igoyear() to recode the numerical values as
factors.
Data distributed with igoR.
Intergovernmental Organizations (version 3), IGO Data Stata Files from the Correlates of War Project.
See the Codebook Version 3 IGO Data for the full reference.
Pevehouse, J. C., Nordstrom, T., McManus, R. W. & Jamison, A. S. (2020). Tracking organizations in the world: The Correlates of War IGO Version 3.0 data sets. Journal of Peace Research, 57(3), 492–503. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1177/0022343319881175")}.
Other data sets:
state_year_format3,
states2016
data("igo_year_format3")
# Show a glimpse.
library(dplyr)
igo_year_format3 %>%
select(ioname:year, spain, france) %>%
filter(year > 1990) %>%
glimpse()
# Prepare a sample of numerical membership values.
sample_igo_year <- igo_year_format3 %>%
as_tibble() %>%
select(ioname:year, spain, france) %>%
filter(year == 1990)
sample_igo_year %>% glimpse()
# Recode the membership columns.
sample_igo_year_recoded <- sample_igo_year %>%
mutate(across(c(spain, france), igo_recode_igoyear))
sample_igo_year_recoded %>% glimpse()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.