| state_year_format3 | R Documentation |
Data on IGOs from 1815 to 2014 at the country-year level. Contains one record per country-year, with years listed at five-year intervals through 1965 and annually thereafter.
data.frame with
15,557 rows. Relevant
fields:
ccode: COW country number, see states2016.
year: Calendar year.
state: Abbreviated state name, identical to variable names in igo_year_format3.
aaaid...wassen: IGO variables containing information on state membership status. See Details.
See Codebook Version 3 IGO Data.
Possible values for the status of a state in the IGO are:
| Category | Numerical Value |
| No Membership | 0 |
| Full Membership | 1 |
| Associate Membership | 2 |
| Observer | 3 |
| Missing data | -9 |
| IGO Not In Existence | -1 |
See the igo_recode_stateyear() section for an easy way to recode the
numerical values into factors.
Raw data used internally by igoR.
Intergovernmental Organizations (v3), The Correlates of War Project (IGO Data Stata Files).
Pevehouse, J. C., Nordstrom, T., McManus, R. W., & Jamison, A. S. (2020). Tracking organizations in the world: The Correlates of War IGO Version 3.0 data sets. Journal of Peace Research, 57(3), 492–503. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1177/0022343319881175")}.
countrycode::countrycode() to convert between different country code
schemes.
Other datasets:
igo_recode_igoyear(),
igo_year_format3,
states2016
data("state_year_format3")
dplyr::tibble(state_year_format3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.